# ENG M 401

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![License: MIT](https://img.shields.io/badge/license-MIT-green)](./LICENSE)
[![Tests](https://github.com/Mcnuget5/ENG-M-401/actions/workflows/main.yaml/badge.svg?branch=main)](https://github.com/Mcnuget5/ENG-M-401/actions)
[![codecov](https://codecov.io/gh/Mcnuget5/ENG-M-401/branch/main/graph/badge.svg?token=MATREXMBM8)](https://codecov.io/gh/Mcnuget5/ENG-M-401)
> "Wow this class sucks." 

Thankfully we have something to do the work for us.

`eng_m` is a simple package which aims to simplify or trivialize the majority of questions from the University of Alberta's ENG M 401 class.

## Installation

`pip install git+https://github.com/Mcnuget5/ENG-M-401`

## Documentation

[`nian.ca/docs/eng_m`](https://nian.ca/docs/eng_m)

(theres nothing there yet)
## License

[mit](./LICENSE)

## Contributing

read [contributing.md](./contributing.md)
